from .mini import MiniNet
from .resnet import (ResNet, resnet18, resnet34, resnet50, resnet101,
                     resnet152, resnext50_32x4d, resnext101_32x8d,
                     wide_resnet50_2, wide_resnet101_2)
